@@ -489,6 +489,12 @@ def examples_bxReposBaseDirsFull():
     cps = collections.OrderedDict() ; cps['baseDir'] = '/bisos/git/auth/bxRepos';
     cps['pbdName'] = 'bxReposRoot' ; cps['vcMode'] = 'auth'
     icm.ex_gCmndMenuItem(cmndName, cps, cmndArgs, verbosity='little')
+
+    cmndName = "pbdUpdate" ; cmndArgs = "all" ;
+    cps = collections.OrderedDict(); cps['baseDir'] = '/bisos/git/anon/ext';
+    cps['pbdName'] = 'extRepos' ; cps['vcMode'] = 'anon'
+    icm.ex_gCmndMenuItem(cmndName, cps, cmndArgs, verbosity='little')
+
     
     # cmndName = "pbdUpdate" ; cmndArgs = "all" ;
     # cps = collections.OrderedDict() ; cps['baseDir'] = '/bisos/vc/git/bxRepos/anon';
@@ -869,7 +875,17 @@ def pbdDict_bxReposRoot(
     
     gitCloneBase( 'blee',  'bx-blee/base',  vcMode)
     gitClone( 'blee/overview',  'bx-blee/overview',  vcMode)
-
+    gitClone(
+        'blee/org-img-link',
+        'bx-blee/org-img-link',
+        vcMode
+    )
+    gitClone(
+        'blee/persian-input-method',
+        'bx-blee/persian-input-method',
+        vcMode
+    )
+    
 
     gitCloneBase( 'bxGenesis',  'bxGenesis/base', vcMode)
     gitClone( 'bxGenesis/overview',  'bxGenesis/overview', vcMode)
@@ -1104,26 +1120,23 @@ def pbdDict_extRepos(
     # So, gitCloneBase should be renamed gitReposCollectionBase and gitRepoBase
     #
 
-    directory( 'emacs')
+    directory('emacs')
     
     gitClone(
         'emacs/emacs-application-framework',
         'manateelazycat/emacs-application-framework',
         vcMode
     )
-
     gitClone(
         'emacs/frame-cmds',
         'emacsmirror/frame-cmds',
         vcMode
     )
-   
     gitClone(
-        'emacs/frame-cmds',
-        'emacsmirror/frame-cmds',
+        'emacs/frame-fns',
+        'emacsmirror/frame-fns',
         vcMode
     )
-
     gitClone(
         'emacs/thumb-frm',
         'emacsmirror/thumb-frm',
